Module work_coalescing_queue

Module work_coalescing_queue 

A work coalescing queue batches work to be done together, for purposes of performance.

Structs

WorkCoalescingQueue
A WorkCoalescingQueue can be used to batch work together for purposes of gaining efficiency. For example, a concurrent log could use the work coalescing queue to batch writes or fsyncs so that many concurrent threads can witness a single write or fsync.

Traits

WorkCoalescingCore
A WorkCoalescingCore is used to batch work and then convert a batch of work into an iterator of outputs.

Functions

register_biometrics
Register the biometrics for the work coalescing queue.